#!/bin/csh -f

# get from markov.ldeo.columbia.edu a table [X Y tsurf] 
# for 1880-1980 C.E. average of annual mean surface temperatures 
# from the GKSS model field correctly regridded to the 5x5 grid 
# ATTENTION: A FILE WITH HARDWIRED NAME gridtable.tsv 
# WILL BE USED (OVERWRITTEN OR CREATED) HERE

if (-e gridtable.tsv ) rm gridtable.tsv
wget http://markov.ldeo.columbia.edu:81/expert/%28/data/free/alexeyk/EMRF/%29readfile/.ECHOg_correct.cdf/.tsurf/T/%28Jul%201880%29%28Jul%201980%29RANGE/T/AVERAGE/gridtable.tsv
touch gridtable.tsv

# strip the header:
awk 'NR>2' gridtable.tsv > X_Y_tsurf.asc

# ignoring the fact that for X (longitude) range [0 360) to be correctly 
# changed to (-180,180], values of X have to be interpreted as longitudes, 
# not regular measures of length, etc.; getting wrong results because of that:
cat X_Y_tsurf.asc | surface -R-177.5/177.5/-87.5/87.5 -I5 -Z1 -Gw1.nc

# adding -fg flag and getting right results:
cat X_Y_tsurf.asc | surface -R-177.5/177.5/-87.5/87.5 -I5 -Z1 -fg -Gc1.nc

# changing the tension from 0 (default) to 0.5 in two previous calculations:
cat X_Y_tsurf.asc | surface -R-177.5/177.5/-87.5/87.5 -I5 -Z1 -T0.5 -Gw2.nc
cat X_Y_tsurf.asc | surface -R-177.5/177.5/-87.5/87.5 -I5 -Z1 -fg -T0.5 -Gc2.nc

# get from markov.ldeo.columbia.edu fields of 
# 1880-1980 C.E. average of annual mean surface temperatures 
# from the GKSS fields correctly regridded to the 5x5 grid
# and from their M07-processed version 
# ATTENTION: A FILE WITH A HARDWIRED NAME data.cdf 
# WILL BE USED (OVERWRITTEN OR CREATED) HERE

if (-e data.cdf ) rm data.cdf
wget http://markov.ldeo.columbia.edu:81/expert/%28/data/free/alexeyk/EMRF/%29readfile/.ECHOg_correct.cdf/.tsurf/T/%28Jul%201880%29%28Jul%201980%29RANGE/T/AVERAGE/data.cdf
mv data.cdf c0.nc
touch c0.nc

wget http://markov.ldeo.columbia.edu:81/expert/%28/data/free/alexeyk/EMRF/%29readfile/.ECHOg_M07.cdf/.tsurf/T/%28Jul%201880%29%28Jul%201980%29RANGE/T/AVERAGE/data.cdf
mv data.cdf w0.nc
touch w0.nc
#

